@@ -38,6 +38,7 @@
 #include "gui_aboutdialog.h"
 #include "gui_settingsdialog.h"
 #include "gui_manualdialog.h"
+#include "text.h"
 
 extern preferencestype preferences;
 
@@ -158,12 +159,12 @@ create_mainwindow (void)
 {
   GtkWidget *mainvbox, *handlebox, *mainmenubar, *vpaned, *clistscrolledwindow,
     *mainscrolledwindow, *maintext, *mainentry, *mainstatusbar, *treeview,
-    *frame, *chathbox, *highvbox, *hbox, *highframe,
+    *frame, *chathbox, *highvbox, *hbox, *highframe, *mainhbox,
     *highentry1, *highentry2, *highentry3, *highentry4, *highentry5,
     *highentry6, *highentry7, *highentry8, *highcheck1, *highcheck2,
     *highcheck3, *highcheck4, *highcheck5, *highcheck6, *highcheck7,
     *highcheck8, *soundcheck;
-  GtkCellRenderer *renderer, *boldrenderer;
+  GtkCellRenderer *renderer, *boldrenderer, *greyrenderer;
   GtkTreeViewColumn *column;
   GtkTextBuffer *buffer, *entrybuffer;
   GtkTreeStore *model;
@@ -172,7 +173,6 @@ create_mainwindow (void)
   servertype *cluster;
   PangoFontDescription *font_description;
   gint pango_size;
-  GtkTooltips *tooltips;
   GtkAccelGroup *key_toggle, *grab_focus;
   gchar *str;
 
@@ -191,8 +191,11 @@ create_mainwindow (void)
   g_object_unref (icon);
   }
 
+  mainhbox = gtk_hbox_new (FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (gui->window), mainhbox);
+
   mainvbox = gtk_vbox_new (FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (gui->window), mainvbox);
+  gtk_container_add (GTK_CONTAINER (mainhbox), mainvbox);
 
   handlebox = gtk_handle_box_new ();
   gtk_box_pack_start (GTK_BOX (mainvbox), handlebox, FALSE, TRUE, 0);
@@ -203,14 +206,16 @@ create_mainwindow (void)
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (clistscrolledwindow),
 				  GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 
-  model = gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING,
+  model = gtk_tree_store_new (N_COLUMNS + 1, G_TYPE_STRING, G_TYPE_STRING,
 			      G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-			      G_TYPE_STRING);
+			      G_TYPE_STRING,G_TYPE_STRING, GDK_TYPE_COLOR );
   treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
   g_object_unref (G_OBJECT (model));
 
   renderer = gtk_cell_renderer_text_new ();
   boldrenderer = gtk_cell_renderer_text_new ();
+  greyrenderer = gtk_cell_renderer_text_new ();
+
   g_object_set (G_OBJECT (boldrenderer), "weight", "bold", NULL);
 
   column =
@@ -255,12 +260,21 @@ create_mainwindow (void)
 
   column =
     gtk_tree_view_column_new_with_attributes (_("Info"), renderer, "text",
-					      INFO_COLUMN, NULL);
+						INFO_COLUMN, NULL);
   gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column), 
     GTK_TREE_VIEW_COLUMN_FIXED);
   gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), TRUE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
-
+	
+	column =
+   gtk_tree_view_column_new_with_attributes (_("Country"), greyrenderer, "text",
+						COUNTRY_COLUMN, NULL);
+  g_object_set(G_OBJECT(greyrenderer), "cell-background", "grey", NULL);
+  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column), 
+    GTK_TREE_VIEW_COLUMN_FIXED);
+  gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), TRUE);
+  gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+		
   gtk_container_add (GTK_CONTAINER (clistscrolledwindow), treeview);
 
   chathbox = gtk_hbox_new (FALSE, 0);
@@ -278,7 +292,7 @@ create_mainwindow (void)
   gtk_box_pack_start (GTK_BOX (chathbox), mainscrolledwindow, TRUE, TRUE, 0);
 
   highframe = gtk_frame_new (NULL);
-  gtk_box_pack_start (GTK_BOX (chathbox), highframe, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (mainhbox), highframe, FALSE, FALSE, 0);
   highvbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (highframe), highvbox);
 
@@ -378,34 +392,34 @@ create_mainwindow (void)
   gtk_paned_add1 (GTK_PANED (vpaned), clistscrolledwindow);
   gtk_paned_add2 (GTK_PANED (vpaned), chathbox);
   gtk_box_pack_start (GTK_BOX (mainvbox), vpaned, TRUE, TRUE, 0);
-  tooltips = gtk_tooltips_new ();
 
-  gtk_tooltips_set_tip(tooltips, highentry1, _("Enter a word to highlight"), NULL);
-  gtk_tooltips_set_tip(tooltips, highentry2, _("Enter a word to highlight"), NULL);
-  gtk_tooltips_set_tip(tooltips, highentry3, _("Enter a word to highlight"), NULL);
-  gtk_tooltips_set_tip(tooltips, highentry4, _("Enter a word to highlight"), NULL);
-  gtk_tooltips_set_tip(tooltips, highentry5, _("Enter a word to highlight"), NULL);
-  gtk_tooltips_set_tip(tooltips, highentry6, _("Enter a word to highlight"), NULL);
-  gtk_tooltips_set_tip(tooltips, highentry7, _("Enter a word to highlight"), NULL);
-  gtk_tooltips_set_tip(tooltips, highentry8, _("Enter a word to highlight"), NULL);
+  gtk_widget_set_tooltip_text(highentry1, _("Enter a word to highlight"));
+  gtk_widget_set_tooltip_text(highentry2, _("Enter a word to highlight"));
+  gtk_widget_set_tooltip_text(highentry3, _("Enter a word to highlight"));
+  gtk_widget_set_tooltip_text(highentry4, _("Enter a word to highlight"));
+  gtk_widget_set_tooltip_text(highentry5, _("Enter a word to highlight"));
+  gtk_widget_set_tooltip_text(highentry6, _("Enter a word to highlight"));
+  gtk_widget_set_tooltip_text(highentry7, _("Enter a word to highlight"));
+  gtk_widget_set_tooltip_text(highentry8, _("Enter a word to highlight"));
+
   str = g_strdup_printf (_("Include prompt [Ctrl+%d]"), 1);
-  gtk_tooltips_set_tip(tooltips, highcheck1, str, NULL);
+  gtk_widget_set_tooltip_text(highcheck1, str);
   str = g_strdup_printf (_("Include prompt [Ctrl+%d]"), 2);
-  gtk_tooltips_set_tip(tooltips, highcheck2, str, NULL);
+  gtk_widget_set_tooltip_text(highcheck2, str);
   str = g_strdup_printf (_("Include prompt [Ctrl+%d]"), 3);
-  gtk_tooltips_set_tip(tooltips, highcheck3, str, NULL);
+  gtk_widget_set_tooltip_text(highcheck3, str);
   str = g_strdup_printf (_("Include prompt [Ctrl+%d]"), 4);
-  gtk_tooltips_set_tip(tooltips, highcheck4, str, NULL);
+  gtk_widget_set_tooltip_text(highcheck4, str);
   str = g_strdup_printf (_("Include prompt [Ctrl+%d]"), 5);
-  gtk_tooltips_set_tip(tooltips, highcheck5, str, NULL);
+  gtk_widget_set_tooltip_text(highcheck5, str);
   str = g_strdup_printf (_("Include prompt [Ctrl+%d]"), 6);
-  gtk_tooltips_set_tip(tooltips, highcheck6, str, NULL);
+  gtk_widget_set_tooltip_text(highcheck6, str);
   str = g_strdup_printf (_("Include prompt [Ctrl+%d]"), 7);
-  gtk_tooltips_set_tip(tooltips, highcheck7, str, NULL);
+  gtk_widget_set_tooltip_text(highcheck7, str);
   str = g_strdup_printf (_("Include prompt [Ctrl+%d]"), 8);
-  gtk_tooltips_set_tip(tooltips, highcheck8, str, NULL);
+  gtk_widget_set_tooltip_text(highcheck8, str);
   str = g_strdup_printf (_("Enable/disable sound [Ctrl+%d]"), 0);
-  gtk_tooltips_set_tip(tooltips, soundcheck, str, NULL);
+  gtk_widget_set_tooltip_text(soundcheck, str);
 
   mainentry = gtk_text_view_new ();
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(mainentry), GTK_WRAP_WORD);
@@ -592,6 +606,7 @@ static void syncprefs (void)
         else if (i == 3) width = COL3WIDTH;
         else if (i == 4) width = COL4WIDTH;
         else if (i == 5) width = COL5WIDTH;
+	else if (i == 6) width = COL6WIDTH;
       }
       g_string_append_printf (w, "%d,", width);
   }
@@ -691,6 +706,7 @@ void
 on_quit_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
   syncprefs ();
+  cleanup_dxcc ();
   cleanup ();
   gtk_main_quit ();
 }
