@@ -1,6 +1,6 @@
 /*
  * xdx - GTK+ DX-cluster client for amateur radio
- * Copyright (C) 2002-2003 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2002-2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,12 +27,16 @@
 #define MESSAGE_TX 2
 
 typedef struct servertype {
-	gchar *host;
-	gchar *port;
-	GIOChannel *rxchannel;
-	guint source_id;
-	gint sockethandle;
+  gchar *host;
+  gchar *port;
+  GIOChannel *rxchannel;
+  guint source_id;
+  gint sockethandle;
   gboolean connected;
+  gint reconnecttimer;
+  gboolean reconnect;
+  gchar *lastcommand;
+  gint keepalivetimer;
 } servertype;
 
 servertype *new_cluster(void);
@@ -40,3 +44,5 @@ gboolean clresolve (servertype *cluster);
 void cldisconnect (GString *msg, gboolean timeout);
 gboolean rx (GIOChannel * channel, GIOCondition cond, gpointer data);
 void tx (GString * message);
+gint reconnect (gpointer data);
+gint send_keepalivepacket (gpointer data);
