@@ -51,7 +51,7 @@ void openurl (const char *url);
 void openmail (const char *url);
 void opensound (const char *file);
 gchar *try_utf8 (const gchar *str);
-gchar *getdate (gboolean formatted);
-gchar *gettime (gboolean formatted);
+gchar *xdxgetdate (gboolean formatted);
+gchar *xdxgettime (gboolean formatted);
 void logconnection (GString *logstr);
 gchar *my_strreplace(const char *str, const char *delimiter, const char *replacement);
